// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Commands helper for the Moodle tiny_copysafewebeditor plugin.
 *
 * @module      tiny_copysafewebeditor/commands
 * @copyright   2025 DeveloperCK <developerck@gmail.com>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

import { getButtonImage } from "editor_tiny/utils";
import { get_string as getString } from "core/str";
import { component, buttonName, icon } from "./common";
import Config from "core/config";
/**
 * Handle the action for your plugin.
 * @param {TinyMCE.editor} editor The tinyMCE editor instance.
 */
const handleAction = (editor) => {
  window.copysafewebeditor = window.copysafewebeditor || {};
  window.copysafewebeditor.editor = editor;
  // Register the command so that it can be invoked by using tinyMCE.activeEditor.execCommand('mceExample');
  window.copysafewebeditor.frame = editor.windowManager.openUrl({
    url: `${Config.wwwroot}/mod/copysafeweb/media-upload.php`,
    inline: 1,
    title: "Upload WEB",
    size: "large",
  });
};

/**
 * Get the setup function for the buttons.
 *
 * This is performed in an async function which ultimately returns the registration function as the
 * Tiny.AddOnManager.Add() function does not support async functions.
 *
 * @returns {function} The registration function to call within the Plugin.add function.
 */
export const getSetup = async () => {
  const [buttonNameTitle, buttonImage] = await Promise.all([
    getString("button_media", component),
    getButtonImage("icon", component),
  ]);

  return (editor) => {
    // Register the Moodle SVG as an icon suitable for use as a TinyMCE toolbar button.
    editor.ui.registry.addIcon(icon, buttonImage.html);

    // Register the startdemo Toolbar Button.
    editor.ui.registry.addButton(buttonName, {
      icon,
      tooltip: buttonNameTitle,
      onAction: () => handleAction(editor),
    });
  };
};
